@@ -1,4 +1,7 @@
 import datetime
+import os
+import sys
+import warnings
 
 name = "SMAC3"
 package_name = "smac"
@@ -19,4 +22,11 @@ copyright = f"""
     Matthias Feurer, André Biedenkapp, Difan Deng, Carolin Benjamins, Tim Ruhkopf, René Sass
     and Frank Hutter
 """
-version = "1.3"
+version = "1.3.3"
+
+
+if os.name != "posix":
+    warnings.warn(
+        f"Detected unsupported operating system: {sys.platform}."
+        "Please be aware, that SMAC might not run on this system."
+    )
