@@ -1,5 +1,6 @@
 import typing
-from subprocess import Popen, PIPE
+
+from subprocess import PIPE, Popen
 
 from smac.configspace import Configuration
 from smac.tae import StatusType
@@ -14,10 +15,10 @@ __version__ = "0.0.1"
 
 
 class ExecuteTARunOld(SerialRunner):
+    """Executes a target algorithm run with a given configuration on a given instance and some
+    resource limitations.
 
-    """Executes a target algorithm run with a given configuration on a given
-    instance and some resource limitations. Uses the original SMAC/PILS format
-    (SMAC < v2.10)
+    Uses the original SMAC/PILS format (SMAC < v2.10).
     """
 
     def run(
@@ -29,9 +30,11 @@ class ExecuteTARunOld(SerialRunner):
         budget: typing.Optional[float] = 0.0,
         instance_specific: str = "0",
     ) -> typing.Tuple[StatusType, float, float, typing.Dict]:
-        """Runs target algorithm <self.ta> with configuration <config> on
-        instance <instance> with instance specifics <specifics> for at most
-        <cutoff> seconds and random seed <seed>
+        """Runs target algorithm <self.ta> with configuration <config> on instance <instance> with
+        instance specifics.
+
+        <specifics> for at most.
+        <cutoff> seconds and random seed <seed>.
 
         Parameters
         ----------
@@ -48,6 +51,7 @@ class ExecuteTARunOld(SerialRunner):
                 Handled by the target algorithm internally. Currently ignored
             instance_specific: str
                 Instance specific information (e.g., domain file or solution)
+
         Returns
         -------
             status: enum of StatusType (int)
@@ -59,56 +63,82 @@ class ExecuteTARunOld(SerialRunner):
             additional_info: dict
                 all further additional run information
         """
-
         if instance is None:
             instance = "0"
         if cutoff is None:
-            cutoff = 99999999999999.
+            cutoff = 99999999999999.0
 
-        stdout_, stderr_ = self._call_ta(config=config,
-                                         instance=instance,
-                                         instance_specific=instance_specific,
-                                         cutoff=cutoff, seed=seed)
+        stdout_, stderr_ = self._call_ta(
+            config=config,
+            instance=instance,
+            instance_specific=instance_specific,
+            cutoff=cutoff,
+            seed=seed,
+        )
 
         status_string = "CRASHED"
         quality = 1234567890.0
         runtime = 1234567890.0
         additional_info = {}  # type: typing.Dict[str, str]
         for line in stdout_.split("\n"):
-            if line.startswith("Result of this algorithm run:") or \
-                    line.startswith("Result for ParamILS") or \
-                    line.startswith("Result for SMAC"):
+            if (
+                line.startswith("Result of this algorithm run:")
+                or line.startswith("Result for ParamILS")
+                or line.startswith("Result for SMAC")
+            ):
                 fields = line.split(":")[1].split(",")
+
+                # If we have more than 6 fields, we combine them all together
+                if len(fields) > 5:
+                    fields[5 : len(fields)] = ["".join(map(str, fields[5 : len(fields)]))]
+
+                    # Make it prettier
+                    for char in [",", ";", "'", "[", "]"]:
+                        fields[5] = fields[5].replace(char, "")
+
                 fields = list(map(lambda x: x.strip(" "), fields))
                 if len(fields) == 5:
                     status_string, runtime_string, _, quality_string, _ = fields
                     additional_info = {}
                 else:
-                    status_string, runtime_string, _, quality_string, _, additional_info_string = fields
+                    (
+                        status_string,
+                        runtime_string,
+                        _,
+                        quality_string,
+                        _,
+                        additional_info_string,
+                    ) = fields
                     additional_info = {"additional_info": additional_info_string}
 
                 runtime = min(float(runtime_string), cutoff)
                 quality = float(quality_string)
 
-        if status_string.upper() in ["SAT", "UNSAT", "SUCCESS"]:
+        if "StatusType." in status_string:
+            status_string = status_string.split(".")[1]
+
+        status_string = status_string.upper()
+
+        if status_string in ["SAT", "UNSAT", "SUCCESS"]:
             status = StatusType.SUCCESS
-        elif status_string.upper() in ["TIMEOUT"]:
+        elif status_string in ["TIMEOUT"]:
             status = StatusType.TIMEOUT
-        elif status_string.upper() in ["CRASHED"]:
+        elif status_string in ["CRASHED"]:
             status = StatusType.CRASHED
-        elif status_string.upper() in ["ABORT"]:
+        elif status_string in ["ABORT"]:
             status = StatusType.ABORT
-        elif status_string.upper() in ["MEMOUT"]:
+        elif status_string in ["MEMOUT"]:
             status = StatusType.MEMOUT
         else:
-            self.logger.warning("Could not parse output of target algorithm. Expected format: "
-                                "\"Result of this algorithm run: <status>,<runtime>,<quality>,<seed>\"; "
-                                "Treating as CRASHED run.")
+            self.logger.warning(
+                "Could not parse output of target algorithm. Expected format: "
+                '"Result of this algorithm run: <status>,<runtime>,<quality>,<seed>"; '
+                "Treating as CRASHED run."
+            )
             status = StatusType.CRASHED
 
         if status in [StatusType.CRASHED, StatusType.ABORT]:
-            self.logger.warning(
-                "Target algorithm crashed. Last 5 lines of stdout and stderr")
+            self.logger.warning("Target algorithm crashed. Last 5 lines of stdout and stderr")
             self.logger.warning("\n".join(stdout_.split("\n")[-5:]))
             self.logger.warning("\n".join(stderr_.split("\n")[-5:]))
 
@@ -131,7 +161,7 @@ class ExecuteTARunOld(SerialRunner):
         # TODO: maybe replace fixed instance specific and cutoff_length (0) to other value
         cmd = []  # type: typing.List[str]
         if not isinstance(self.ta, (list, tuple)):
-            raise TypeError('self.ta needs to be of type list or tuple, but is %s' % type(self.ta))
+            raise TypeError("self.ta needs to be of type list or tuple, but is %s" % type(self.ta))
         cmd.extend(self.ta)
         cmd.extend([instance, instance_specific, str(cutoff), "0", str(seed)])
         for p in config:
@@ -139,8 +169,7 @@ class ExecuteTARunOld(SerialRunner):
                 cmd.extend(["-" + str(p), str(config[p])])
 
         self.logger.debug("Calling: %s" % (" ".join(cmd)))
-        p = Popen(cmd, shell=False, stdout=PIPE, stderr=PIPE,
-                  universal_newlines=True)
+        p = Popen(cmd, shell=False, stdout=PIPE, stderr=PIPE, universal_newlines=True)
         stdout_, stderr_ = p.communicate()
 
         self.logger.debug("Stdout: %s" % stdout_)
